package org.acme.validation;

import io.quarkus.test.junit.QuarkusIntegrationTest;

@QuarkusIntegrationTest
public class BookResourceIT extends BookResourceTest {

}